@@ -7,18 +7,20 @@
 #' @param plot Logical, defaults to TRUE
 #' @param resolution The percentage of edges to iteratively alter. One percent is default, increase to go quicker. 
 #' @param reps The number of repititions to do for each level of perturbation. Decrease to make it go quicker. 
-#' @param cluster_assign Dataframe. Option to provide confirmatory cluster labels contained in the dataframe. Dataframe has 2 columns,
-#' the first referring to node number, and the second an integer variable referring to cluster label/assignment.
 #' @param errbars Logical, defaults to FALSE. Option to add error bars of one standard deviation above and below the mean for each point.
-#' @param dist Option to rewire in a manner that retains overall graph weight regardless of distribution of edge weights. 
-#' This option is invoked by putting any text into this field. Defaults to "NegBinom" for negative binomial.
 #' @export perturbR 
 #' @examples 
-#' perturbR(exampledata, plot=FALSE, resolution=0.10, reps=1, 
-#' cluster_assign = NULL, errbars = FALSE, dist = "Normal")
+#' perturbR(exampledata, plot=FALSE, resolution=0.10, reps=1, errbars = FALSE)
 
 
-perturbR <- evalClust <- function(sym.matrix, plot = TRUE, resolution = 0.01, reps = 100, cluster_assign = NULL, errbars = FALSE, dist = "NegBinom"){
+perturbR <- evalClust <- function( sym.matrix, 
+                                   plot = TRUE, 
+                                   resolution = 0.01, 
+                                   reps = 100,
+                                   errbars = FALSE ){
+  
+  cluster_assign = NULL # removed option for now to have a priori clusters
+  dist = "NegBinom"     # removed argument for now to have neg binom or diff distribution
   
   if (!isSymmetric(unname(sym.matrix))){ 
     # only recommended for count graphs; 
@@ -28,8 +30,8 @@ perturbR <- evalClust <- function(sym.matrix, plot = TRUE, resolution = 0.01, re
     
     stop(paste("Symmetric matrix required."))
     
-  
-    } else{
+    
+  } else{
     
     sym.matrixg                  <- as.data.frame(sym.matrix)
     diag(sym.matrixg)            <- 0
@@ -38,8 +40,8 @@ perturbR <- evalClust <- function(sym.matrix, plot = TRUE, resolution = 0.01, re
     
   }
   if(is.null(cluster_assign)){
-  truemembership <- walktrap.community(g, weights = E(g)$weight, steps = 4)$membership
-  
+    truemembership <- walktrap.community(g, weights = E(g)$weight, steps = 4)$membership
+    
   } else {
     truemembership <- cluster_assign[order(cluster_assign[,1]),]
     truemembership <- truemembership[,2]
@@ -55,7 +57,7 @@ perturbR <- evalClust <- function(sym.matrix, plot = TRUE, resolution = 0.01, re
   VI[,1]           <- 0 # when 0 edges are perturbed no variation of information
   ARI[,1]          <- 1 # when 0 edges are perturbed ARI = 1
   iters            <- seq(1,length(percent))
-
+  
   for(p in 1:reps){ # for each degree of perturbation run 100 times
     
     for(k in 2:length(iters)) {
@@ -74,32 +76,38 @@ perturbR <- evalClust <- function(sym.matrix, plot = TRUE, resolution = 0.01, re
     
   }
   
+  # randomly order vector to see modularity distribution
+  modularity.randclust <- matrix(NA, reps, 1)
+  
+  for (p in 1:reps)
+    modularity.randclust[p] <-modularity(g, sample(truemembership))
+  
   # explicitly change 10 and 20 percent of community affiliations to add lines to graph
   comms <- unique(truemembership)
   lengths <- NULL
   
   for (p in 1:length(comms))
     lengths[p] <- length(which(truemembership == comms[p]))
-
-#  max       <- which(lengths == max(lengths))
+  
+  #  max       <- which(lengths == max(lengths))
   perc10    <- round(.10*length(truemembership))
   perc20    <- round(.20*length(truemembership))
-#  tochange  <- which(truemembership == comms[max[1]])
+  #  tochange  <- which(truemembership == comms[max[1]])
   tochange10 <- sample(seq(1,length(sym.matrix[,1])), perc10)
   tochange20 <- sample(seq(1,length(sym.matrix[,1])), perc20)
   
   rep10arim <- matrix(,100, 1)
   rep10vim <- matrix(,100, 1)
   for (k in 1:100){
-  changed10 <- truemembership
-
-  for (p in 1:perc10){
-    commchange <- comms[-truemembership[tochange10[p]]]
-    changed10[tochange10[p]] <- commchange[sample(length(commchange), 1)] #randomly select which community it gets assigned
+    changed10 <- truemembership
+    
+    for (p in 1:perc10){
+      commchange <- comms[-truemembership[tochange10[p]]]
+      changed10[tochange10[p]] <- commchange[sample(length(commchange), 1)] #randomly select which community it gets assigned
     }
-  
-  rep10arim[k]  <- arandi(changed10, truemembership)
-  rep10vim[k]   <- vi.dist(changed10, truemembership)
+    
+    rep10arim[k]  <- arandi(changed10, truemembership)
+    rep10vim[k]   <- vi.dist(changed10, truemembership)
   }
   rep10ari  <- matrix(mean(rep10arim), 1, length(percent))
   rep10vi   <- matrix(mean(rep10vim), 1, length(percent))
@@ -109,10 +117,10 @@ perturbR <- evalClust <- function(sym.matrix, plot = TRUE, resolution = 0.01, re
   for (k in 1:100){
     changed20 <- truemembership
     
-  for (p in 1:perc20){
-    commchange <- comms[-truemembership[tochange20[p]]]
-    changed20[tochange20[p]] <- commchange[sample(length(commchange), 1)] #randomly select which community it gets assigned
-  }
+    for (p in 1:perc20){
+      commchange <- comms[-truemembership[tochange20[p]]]
+      changed20[tochange20[p]] <- commchange[sample(length(commchange), 1)] #randomly select which community it gets assigned
+    }
     
     rep20arim[k]  <- arandi(changed20, truemembership)
     rep20vim[k]   <- vi.dist(changed20, truemembership)
@@ -126,15 +134,16 @@ perturbR <- evalClust <- function(sym.matrix, plot = TRUE, resolution = 0.01, re
   modularity.rando <- matrix(,nrow = reps, ncol = length(percent))
   plotVI           <- NULL
   plotARI          <- NULL
-  percentlab       <- NULL
-  
+
   diag(new.v)      <- 0
   new.v[new.v< 0]  <- 0
   new.g            <- graph.adjacency(as.matrix(new.v), mode = "undirected", weighted = TRUE)
   modularity.rando[,1]       <-  modularity(walktrap.community(new.g, weights = E(new.g)$weight, steps = 4))
   
+  percentlab <- percent/n.elements
+  
   if (plot == TRUE){
-
+    
     VI.rando[,1] <- 0 #when 0 edges are disrupted no variation of information
     ARI.rando[,1]<- 1 #when 0 edges are disrupted ARI = 1
     
@@ -156,23 +165,23 @@ perturbR <- evalClust <- function(sym.matrix, plot = TRUE, resolution = 0.01, re
     }
     
     # plots of ARI and VI compared to original
-    percentlab <- percent/n.elements
-  
-    plotARI <- plot(percentlab, colMeans(ARI),  pch=19, col = "black", main = "Comparison of original result against perturbed graphs: ARI", xlab = "Proportion Perturbed", ylab = "Mean ARI")
-    if(errbars == TRUE)
-    suppressWarnings(arrows(percentlab, (colMeans(ARI)-apply(ARI, 2, sd)), percentlab, (colMeans(ARI)+apply(ARI, 2, sd)), length=0.05, angle=90, code=3))
-    suppressWarnings(plotARI <-  points(percentlab, colMeans(ARI.rando), pch=19, col = "red") + lines(percentlab, rep10ari) + lines(percentlab, rep20ari))
-    if(errbars == TRUE)
-    suppressWarnings(arrows(percentlab, (colMeans(ARI.rando)-apply(ARI.rando, 2, sd)), percentlab, (colMeans(ARI.rando)+apply(ARI.rando, 2, sd)), length=0.05, angle=90, code=3))
     
-    plotVI <- plot(percentlab, colMeans(VI.rando), ylim=range(c(0, colMeans(VI.rando)+apply(VI.rando, 2, sd))), pch=19,
+    plotARI <- plot(percentlab, colMeans(ARI),  pch=16, col = "black", main = "Comparison of original result against perturbed graphs: ARI", xlab = "Proportion Perturbed", ylab = "Mean ARI")
+    if(errbars == TRUE)
+      graphics::arrows(percentlab, (colMeans(ARI)-apply(ARI, 2, stats::sd)), percentlab, (colMeans(ARI)+apply(ARI, 2, stats::sd)), length=0.05, angle=90, code=3)
+    plotARI <-  points(percentlab, colMeans(ARI.rando), pch=18, col = "red") + lines(percentlab, rep10ari) + lines(percentlab, rep20ari)
+    if(errbars == TRUE)
+      graphics::arrows(percentlab, (colMeans(ARI.rando)-apply(ARI.rando, 2, stats::sd)), percentlab, (colMeans(ARI.rando)+apply(ARI.rando, 2, stats::sd)), length=0.05, angle=90, code=3)
+    
+    plotVI <- plot(percentlab, colMeans(VI.rando), ylim=range(c(0, colMeans(VI.rando)+apply(VI.rando, 2, stats::sd))), pch=18,
                    col = "red", main = "Comparison of original result against perturbed graphs: VI", xlab = "Proportion Perturbed", ylab = "Mean VI")
     if(errbars == TRUE)
-      suppressWarnings(arrows(percentlab, (colMeans(VI.rando)-apply(VI.rando, 2, sd)), percentlab, (colMeans(VI.rando)+apply(VI.rando, 2, sd)), length=0.05, angle=90, code=3))
-    plotVI <- plotVI + points(percentlab, colMeans(VI), pch=19, col = "black") + lines(percentlab, rep10vi) + lines(percentlab, rep20vi)
+      graphics::arrows(percentlab, (colMeans(VI.rando)-apply(VI.rando, 2, stats::sd)), percentlab, (colMeans(VI.rando)+apply(VI.rando, 2, stats::sd)), length=0.05, angle=90, code=3)
+    plotVI <- plotVI + points(percentlab, colMeans(VI), pch=16, col = "black") + lines(percentlab, rep10vi) + lines(percentlab, rep20vi)
     if(errbars == TRUE)
-      suppressWarnings(arrows(percentlab, (colMeans(VI)-apply(VI, 2, sd)), percentlab, (colMeans(VI)+apply(VI, 2, sd)), length=0.05, angle=90, code=3))
-    }
+      graphics::arrows(percentlab, (colMeans(VI)-apply(VI, 2, stats::sd)), percentlab, (colMeans(VI)+apply(VI, 2, stats::sd)), length=0.05, angle=90, code=3)
+    
+  }
   
   distribution <- sort(as.matrix(modularity.rando[,length(percent)]))
   cutoff <- distribution[round(length(distribution)*.95)]
